package com.glxp.udidl.admin.controller.collect;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.text.CharSequenceUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.github.pagehelper.PageInfo;
import com.glxp.udidl.admin.entity.chs.CodeRel;
import com.glxp.udidl.admin.entity.collect.RelCodeBatch;
import com.glxp.udidl.admin.enums.ResultEnum;
import com.glxp.udidl.admin.req.collect.RelCodeBatchRequest;
import com.glxp.udidl.admin.req.collect.RelCodeDetailRequest;
import com.glxp.udidl.admin.res.BaseResponse;
import com.glxp.udidl.admin.res.PageSimpleResponse;
import com.glxp.udidl.admin.res.collect.RelCodeBatchResponse;
import com.glxp.udidl.admin.service.collect.RelCodeBatchService;
import com.glxp.udidl.admin.util.ResultVOUtils;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

@Slf4j
@RestController
public class RelCodeBatchController {

    @Resource
    private RelCodeBatchService relCodeBatchService;


    /**
     * 手动添加
     * @param relCodeBatchRequest
     * @return
     */
    @PostMapping("/udiwms/relCode/batch/add")
    public BaseResponse add(@RequestBody @Valid RelCodeBatchRequest relCodeBatchRequest, BindingResult bindingResult) {
        relCodeBatchService.add(relCodeBatchRequest);
        return ResultVOUtils.success("添加成功！");
    }

    /**
     * 添加拼箱
     * @param relCodeBatchRequest
     * @return
     */
    @PostMapping("/udiwms/relCode/batch/addList")
    public BaseResponse addRelCodeSpellBox(@RequestBody @Valid List<RelCodeBatchRequest> relCodeBatchRequest,BindingResult bindingResult) {
        relCodeBatchService.addRelCodeSpellBox(relCodeBatchRequest);
        return ResultVOUtils.success("添加成功！");
    }

    @GetMapping("/udiwms/relCode/batch/filter")
    public BaseResponse list(RelCodeBatchRequest relCodeBatchRequest, BindingResult bindingResult) {
        List<RelCodeBatchResponse> relCodeBatchResponses = relCodeBatchService.filterList(relCodeBatchRequest);
        PageInfo<RelCodeBatchResponse> pageInfo = new PageInfo<>(relCodeBatchResponses);
        PageSimpleResponse<RelCodeBatchResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(relCodeBatchResponses);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @GetMapping("/udiwms/relCode/batch/get")
    public BaseResponse get(@RequestParam("id") Long id) {
        RelCodeBatch relCodeBatch = relCodeBatchService.getById(id);
        return ResultVOUtils.success(relCodeBatch);
    }

    @GetMapping("/udiwms/relCode/batch/delete")
    public BaseResponse delete(@RequestParam("id") Long id) {
        relCodeBatchService.delete(id);
        return ResultVOUtils.success("删除成功");
    }


    @PostMapping("/udiwms/relCode/batch/update")
    public BaseResponse update(@RequestBody @Valid RelCodeBatch relCodeBatch) {
        relCodeBatchService.updateById(relCodeBatch);
        return ResultVOUtils.success("修改成功！");
    }



    @GetMapping("/udiwms/relCode/batch/deleteDetail")
    public BaseResponse deleteDetail(@RequestParam("curCode") String curCode) {
        relCodeBatchService.deleteDetail(curCode);
        return ResultVOUtils.success("删除成功");
    }


    @PostMapping("/udiwms/relCode/batch/deleteAllDetail")
    public BaseResponse deleteAllDetail(@RequestBody List<RelCodeDetailRequest> detailList) {
        relCodeBatchService.deleteAllDetail(detailList);
        return ResultVOUtils.success("清空成功");
    }

    @GetMapping("/udiwms/relCode/detailByParentCode")
    public BaseResponse detailByParentCode(@RequestParam("parentCode") String parentCode) {
        if (StrUtil.isBlank(parentCode)) return ResultVOUtils.error(500,"层级编码格式错误!");
        return ResultVOUtils.success(relCodeBatchService.detailByParentCode(parentCode));
    }

    @PostMapping("/udiwms/relCode/checkCode")
    public BaseResponse checkCode(@RequestBody List<String> codeList) {
        if (CollUtil.isEmpty(codeList)){
            return ResultVOUtils.error(ResultEnum.DATA_ERROR,"参数错误");
        }
        List<String> list = relCodeBatchService.checkCode(codeList);
        return ResultVOUtils.success(list);
    }

}
