package com.glxp.udidl.admin.service.tyapi;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.udidl.admin.res.tyapi.CompanyBaseResponse;
import com.glxp.udidl.admin.res.tyapi.ContactResponse;
import com.glxp.udidl.admin.res.tyapi.OpenSearchResponse;
import com.glxp.udidl.admin.res.tyapi.SupplierResponse;
import com.glxp.udidl.admin.util.OkHttpCli;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

@Slf4j
@Service
public class TyDlHttpClient {

    @Resource
    OkHttpCli okHttpCli;
    @Value("${TY_AUTHORIZATION}")
    String suthorization;

    String supplyUrl = "http://open.api.tianyancha.com/services/open/m/supply/2.0";     //946
    String baseInfoUrl = "http://open.api.tianyancha.com/services/open/ic/baseinfoV2/2.0"; //818
    String contactUrl = "http://open.api.tianyancha.com/services/open/ic/contact";      //1046
    String openSearchUrl = "http://open.api.tianyancha.com/services/open/search/2.0";   //816

    String[] headers = {"Authorization", suthorization};

    //获取供应商列表
    public SupplierResponse getSupplier(String hospital, String year, Integer pageNum, Integer pageSize) {
        Map<String, String> params = new HashMap<>();
        params.put("keyword", hospital);
        params.put("pageNum", pageNum + "");
        params.put("pageSize", pageSize + "");
        if (StrUtil.isNotEmpty(year)) {
            params.put("year", year);
        }
        String response = okHttpCli.doGet(supplyUrl, params, headers);
        log.info(response);
        SupplierResponse baseResponse = JSONObject.parseObject(response, new TypeReference<SupplierResponse>() {
        });
        return baseResponse;
    }

    //获取企业相信信息
    public CompanyBaseResponse getBaseInfo(String company) {
        Map<String, String> params = new HashMap<>();
        params.put("keyword", company);
        String response = okHttpCli.doGet(baseInfoUrl, params, headers);
        log.info(response);
        CompanyBaseResponse baseResponse = JSONObject.parseObject(response, new TypeReference<CompanyBaseResponse>() {
        });
        return baseResponse;
    }

    //获取企业相信信息
    public ContactResponse getContact(String company) {
        Map<String, String> params = new HashMap<>();
        params.put("keyword", company);
        String response = okHttpCli.doGet(contactUrl, params, headers);
        log.info(response);
        ContactResponse baseResponse = JSONObject.parseObject(response, new TypeReference<ContactResponse>() {
        });
        return baseResponse;
    }


    //获取企业相信信息
    public OpenSearchResponse getOpenSearch(String company) {
        Map<String, String> params = new HashMap<>();
        params.put("keyword", company);
        String response = okHttpCli.doGet(openSearchUrl, params, headers);
        log.info(response);
        OpenSearchResponse baseResponse = JSONObject.parseObject(response, new TypeReference<OpenSearchResponse>() {
        });
        return baseResponse;
    }

}
