package com.glxp.udidl.admin.service.tyapi;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.glxp.udidl.admin.entity.tyapi.TyContactInfoEntity;
import com.glxp.udidl.admin.req.tyapi.TyImportSupRequest;
import com.glxp.udidl.admin.res.tyapi.SupplierResponse;
import com.glxp.udidl.admin.util.DateUtil;
import com.glxp.udidl.admin.util.IntUtil;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.glxp.udidl.admin.entity.tyapi.TySupplierEntity;
import com.glxp.udidl.admin.dao.tyapi.TySupplierMapper;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Date;
import java.util.List;

@Service
public class TySupplierService extends ServiceImpl<TySupplierMapper, TySupplierEntity> {
    @Resource
    TyDlHttpClient tyDlHttpClient;
    @Resource
    TySupplierMapper tySupplierMapper;

    public List<TySupplierEntity> downloadByName(String hospital, String year) {
        Integer pageNum = 1;
        Integer pageSize = 20;
        if (tySupplierMapper.exists(new QueryWrapper<TySupplierEntity>().eq("hospName", hospital))) {
            log.error(hospital + "供应商列表已存在重复下载！");
        } else {
            while (true) {
                SupplierResponse supplierResponse = tyDlHttpClient.getSupplier(hospital, year, pageNum, pageSize);
                if (supplierResponse.getErrorCode() == 0) {
                    List<SupplierResponse.ResultDTO.PageBeanDTO.SupplierDTO> supplierDTOS = supplierResponse.getResult().getPageBean().getResult();
                    List<TySupplierEntity> tySupplierEntities = BeanUtil.copyToList(supplierDTOS, TySupplierEntity.class);
                    if (CollUtil.isNotEmpty(supplierDTOS)) {
                        for (TySupplierEntity tySupplierEntity : tySupplierEntities) {
                            tySupplierEntity.setHospName(tySupplierEntity.getSupplier_name());
                            tySupplierEntity.setUpdateTime(new Date());
                            tySupplierEntity.setYear(DateUtil.formatDate(IntUtil.value(tySupplierEntity.getAnnouncement_date()), "yyyy"));
                        }
                    }
                    tySupplierMapper.insertBatch(tySupplierEntities);
                    if (CollUtil.isNotEmpty(supplierDTOS) && supplierDTOS.size() == 20) {
                        pageNum = pageNum + 1;
                    } else {
                        break;
                    }
                }
            }
        }
        List<TySupplierEntity> tySupplierEntities = tySupplierMapper.selectList(new QueryWrapper<TySupplierEntity>().eq("hospName", hospital));
        return tySupplierEntities;
    }

    public List<TySupplierEntity> downloadByCode(String code, String year) {
        Integer pageNum = 1;
        Integer pageSize = 20;
        if (tySupplierMapper.exists(new QueryWrapper<TySupplierEntity>().eq("creditCodeFk", code))) {
            log.error(code + "供应商列表已存在重复下载！");
        } else {
            while (true) {
                SupplierResponse supplierResponse = tyDlHttpClient.getSupplier(code, year, pageNum, pageSize);
                if (supplierResponse.getErrorCode() == 0) {
                    List<SupplierResponse.ResultDTO.PageBeanDTO.SupplierDTO> supplierDTOS = supplierResponse.getResult().getPageBean().getResult();
                    List<TySupplierEntity> tySupplierEntities = BeanUtil.copyToList(supplierDTOS, TySupplierEntity.class);
                    if (CollUtil.isNotEmpty(supplierDTOS)) {
                        for (TySupplierEntity tySupplierEntity : tySupplierEntities) {
                            tySupplierEntity.setHospName(tySupplierEntity.getSupplier_name());
                            tySupplierEntity.setCreditCodeFk(code);
                            tySupplierEntity.setUpdateTime(new Date());
                            tySupplierEntity.setYear(DateUtil.formatDate(IntUtil.value(tySupplierEntity.getAnnouncement_date()), "yyyy"));
                        }
                    }
                    tySupplierMapper.insertBatch(tySupplierEntities);
                    if (CollUtil.isNotEmpty(supplierDTOS) && supplierDTOS.size() == 20) {
                        pageNum = pageNum + 1;
                    } else {
                        break;
                    }
                }
            }
        }
        List<TySupplierEntity> tySupplierEntities = tySupplierMapper.selectList(new QueryWrapper<TySupplierEntity>().eq("creditCodeFk", code));
        return tySupplierEntities;
    }


    public List<TySupplierEntity> filterList(TyImportSupRequest tyImportSupRequest) {
        if (null == tyImportSupRequest) {
            return Collections.emptyList();
        }
        if (null != tyImportSupRequest.getPage() && null != tyImportSupRequest.getLimit()) {
            PageHelper.offsetPage((tyImportSupRequest.getPage() - 1) * tyImportSupRequest.getLimit(), tyImportSupRequest.getLimit());
        }
        return tySupplierMapper.filterList(tyImportSupRequest);
    }

}
